"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.printLoadingMessage = exports.showCursor = exports.hideCursor = exports.clear = exports.printErrorMessage = exports.printSuccessMessage = exports.printInfoMessage = exports.runProgram = exports.addCommand = void 0;
var commander_1 = require("commander");
function addCommand(config) {
    var cm = commander_1.program
        .command(config.command)
        .description(config.description || '')
        .action(function (flags) { return config.action(flags); });
    config.flags.forEach(function (flag) {
        cm.option(flag.flag + ' <value>', flag.description || '', flag.default);
    });
}
exports.addCommand = addCommand;
function runProgram() {
    commander_1.program.parse();
}
exports.runProgram = runProgram;
var ANSI_PREFIX = '\x1b[';
var HIDE_CURSOR = ANSI_PREFIX + '?25l';
var SHOW_CURSOR = ANSI_PREFIX + '?25h';
var MOVE_CURSOR_TO_NEXT_LINE = ANSI_PREFIX + '1G';
var GREEN_TEXT = ANSI_PREFIX + '32m';
var WHITE_TEXT = ANSI_PREFIX + '37m';
var RED_TEXT = ANSI_PREFIX + '31m';
function printInfoMessage(text) {
    console.log(WHITE_TEXT, text);
}
exports.printInfoMessage = printInfoMessage;
function printSuccessMessage(text) {
    console.log(GREEN_TEXT, text);
}
exports.printSuccessMessage = printSuccessMessage;
function printErrorMessage(text) {
    console.log(RED_TEXT, text);
}
exports.printErrorMessage = printErrorMessage;
function clear() {
    console.clear();
}
exports.clear = clear;
function hideCursor() {
    console.log(HIDE_CURSOR);
}
exports.hideCursor = hideCursor;
function showCursor() {
    console.log(SHOW_CURSOR);
}
exports.showCursor = showCursor;
var loadingInterval;
function printLoadingMessage(text) {
    var process = require('process');
    if (!process.stdout.isTTY) {
        console.log(text);
        return;
    }
    var std = process.stdout;
    var dots = ['⠋', '⠙', '⠹', '⠸', '⠼', '⠴', '⠦', '⠧', '⠇', '⠏'];
    var spinnerFrames = dots;
    var index = 0;
    var log = function () {
        var line = spinnerFrames[index];
        if (!line) {
            index = 0;
            line = spinnerFrames[index];
        }
        process.stdout.clearLine();
        process.stdout.cursorTo(0);
        std.write('\x1b[36m' + line + '\x1b[37m' + ' ' + text);
        index = index >= spinnerFrames.length ? 0 : index + 1;
    };
    clearInterval(loadingInterval);
    log();
    loadingInterval = setInterval(log, 100);
}
exports.printLoadingMessage = printLoadingMessage;
